@@ -170,10 +170,10 @@ class BaseAudit:
             irec.criteria += query_builder.dyn_crit(usr_id, 't', 'who')
 
         if tname:
-            irec.criteria += query_builder.dyn_crit(tname, 't', 'tbl_id')
+            irec.criteria += query_builder.dyn_crit(tname, 'a', 'tbl_id')
 
             if pk:
-                irec.criteria += query_builder.dyn_crit(pk, 't', 'tbl_key')
+                irec.criteria += query_builder.dyn_crit(pk, 'a', 'tbl_key')
 
         if actions:
             irec.criteria += query_builder.dyn_list(actions, 'a', 'action')
